==> order-center-api-3.2.3-CLOUD-DEV-20241024.063421-11-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspTaskBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspTaskBo
 * 说明:
 * 时间:2022/3/10 12:30
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspTaskBo implements Serializable {

    private static final long serialVersionUID = -2586347390622078215L;

    /**id*/
    private Long id;

    /**任务实例id*/
    private String taskInstId;

    /**流程实例id*/
    private String procInstId;

    /**单据id*/
    private Long objId;

    /**单据类型:1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单     99.其他*/
    private Integer objType;

    /**单据类型翻译*/
    private String objTypeStr;

    /**所在环节*/
    private String procState;

    /**创建时间*/
    private Date createTime;

    /**任务处理数据*/
    private List<UocGetSaleOrderDetailServiceRspTaskDealBo> taskDealBo;

    /**处理人ID*/
    private String dealOperId;

    /**处理人姓名*/
    private String dealOperName;

    /**处理结果*/
    private Integer dealResult;

    /**处理备注*/
    private String dealRemark;

    /**审批对象业务类型 1调价 2订单审批*/
    private Integer objBusiType;


    /**加签标识 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务*/
    private Integer taskSignTag;

    /**完结标志0未完结1已完结*/
    private Integer finishTag;


    /**处理人*/
    private String dealId;

    /**处理对象名称*/
    private String dealName;
    /**审批业务类型查询key*/
    private String auditObjBusiTypeQryKey;
    /**审批处理结果查询key*/
    private String auditDealResultQryKey;


    /**完成时间*/
    private Date finishTime;

    /**查询时间*/
    private String finishTimeStr;
    
    private List<String> dealIdList;
}

==> order-center-api-3.3.0-CLOUD-DEV-20251124.032440-3-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspTaskBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.dyc.base.core.dictionary.annotation.DictField;
import com.tydic.dyc.oc.constants.UocDicConstant;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspTaskBo
 * 说明:
 * 时间:2022/3/10 12:30
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspTaskBo implements Serializable {

    private static final long serialVersionUID = -2586347390622078215L;

    /**id*/
    private Long id;

    /**任务实例id*/
    private String taskInstId;

    /**流程实例id*/
    private String procInstId;

    /**单据id*/
    private Long objId;

    /**单据类型:1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单     99.其他*/
    @DictField(busiCenter = "UOC_PRO",pCode = UocDicConstant.OBJ_TYPE.P_CODE)
    private Integer objType;

    /**单据类型翻译*/
    private String objTypeStr;

    /**所在环节*/
    private String procState;

    /**创建时间*/
    private Date createTime;

    /**任务处理数据*/
    private List<UocGetSaleOrderDetailServiceRspTaskDealBo> taskDealBo;

    /**处理人ID*/
    private String dealOperId;

    /**处理人姓名*/
    private String dealOperName;

    /**处理结果*/
    private Integer dealResult;

    /**处理备注*/
    private String dealRemark;

    /**审批对象业务类型 1调价 2订单审批*/
    private Integer objBusiType;


    /**加签标识 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务*/
    private Integer taskSignTag;

    /**完结标志0未完结1已完结*/
    private Integer finishTag;


    /**处理人*/
    private String dealId;

    /**处理对象名称*/
    private String dealName;
    /**审批业务类型查询key*/
    private String auditObjBusiTypeQryKey;
    /**审批处理结果查询key*/
    private String auditDealResultQryKey;


    /**完成时间*/
    private Date finishTime;

    /**查询时间*/
    private String finishTimeStr;
    
    private List<String> dealIdList;
    /**
     * 任务待办人id
     */
    private Long taskUserId;
    /**
     * 任务待办人名称
     */
    private String taskUserName;

    private String stepCode;
}
